require 'spec_helper'
require 'rhosts/commands/console'

describe 'Console' do
  include_context 'capture_stderr'

  before do
    RHosts::Console.any_instance.stub(:start).and_return(nil)
  end

  context 'hosts file is not writable' do
    before do
      RHosts::Filer::Mock.writable(false)
    end

    context 'and sudo flag is false' do
      before do
        RHosts::Console.stub(:load_run_command) do
          RHosts.configure{ |c| c.sudo = false }
        end
      end

      it 'should display error message and exit' do
        err = capture_stderr do
          expect{ RHosts::Console.start }.to raise_error(SystemExit)
        end

        expect(err.chomp).to eq('Hosts file is not writable. Please check permission')
      end
    end

    context 'and sudo flag is true' do
      before do
        RHosts::Console.stub(:load_run_command) do
          RHosts.configure{ |c| c.sudo = true }
        end
      end

      it 'should not display error message and exit' do
        expect{ RHosts::Console.start }.not_to raise_error(SystemExit)
      end
    end
  end

  context 'hosts file is writable' do
    before do
      RHosts::Filer::Mock.writable(true)
    end

    context 'and sudo flag is false' do
      before do
        RHosts::Console.stub(:load_run_command) do
          RHosts.configure{ |c| c.sudo = false }
        end
      end

      it 'should not display error message and exit' do
        expect{ RHosts::Console.start }.not_to raise_error(SystemExit)
      end
    end

    context 'and sudo flag is true' do
      before do
        RHosts::Console.stub(:load_run_command) do
          RHosts.configure{ |c| c.sudo = true }
        end
      end

      it 'should not display error message and exit' do
        expect{ RHosts::Console.start }.not_to raise_error(SystemExit)
      end
    end
  end
end
